@@ -94,17 +94,17 @@ def get_simulator_short_name(simulator):
 
 
 def get_simulator_long_name(simulator):
-    if simulator == simulators_enum.VIVADO:
+    if simulator == simulators_enum.VIVADO or simulator == "viv":
         return "vivado"
-    elif simulator == simulators_enum.VCS:
+    elif simulator == simulators_enum.VCS or simulator == "vcs":
         return "vcs"
-    elif simulator == simulators_enum.METRICS:
+    elif simulator == simulators_enum.METRICS or simulator == "mdc":
         return "metrics"
-    elif simulator == simulators_enum.XCELIUM:
+    elif simulator == simulators_enum.XCELIUM or simulator == "xcl":
         return "xcelium"
-    elif simulator == simulators_enum.QUESTA:
+    elif simulator == simulators_enum.QUESTA or simulator == "qst":
         return "questa"
-    elif simulator == simulators_enum.RIVIERA:
+    elif simulator == simulators_enum.RIVIERA or simulator == "riv":
         return "riviera"
 
 
