@@ -335,17 +335,17 @@ def prep_ip_for_cmp(ip, sim_job):
 
 
 
-def cmp_vivado_project(ip, sim_job):
+def cmp_vivado_project(ip, sim_job, sub_ip=False, owner_ip=None):
     ip_str = f"{ip.vendor}/{ip.name}"
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     defines = sim_job.cmp_args
     dep_list = get_dep_list(ip, sim_job)
     timestamp_start = common.timestamp()
-    log_file_paths = do_cmp_vivado_project(ip, dep_list, sim_job)
+    log_file_paths = do_cmp_vivado_project(ip, dep_list, sim_job, sub_ip, owner_ip)
     if not sim_job.dry_run:
         timestamp_end = common.timestamp()
         errors = scan_cmp_log_file_for_errors(log_file_paths[0], sim_job)
-        errors.append(scan_cmp_log_file_for_errors(log_file_paths[1], sim_job))
+        errors += scan_cmp_log_file_for_errors(log_file_paths[1], sim_job)
         if len(errors):
             common.error("Errors during compilation of Vivado Project IP '" + ip_str + "':")
             for error in errors:
@@ -634,35 +634,45 @@ def cmp_flist(vendor, name, flist_path, deps, sim_job, local, licensed=True):
 
 
 
-def do_cmp_vivado_project(ip, deps, sim_job, local):
+def do_cmp_vivado_project(ip, deps, sim_job, sub_ip=False, owner_ip=None):
     ip_str = f"{ip.vendor}/{ip.name}"
     ip_dir_name = f"{ip.vendor}__{ip.name}"
     sim_str = common.get_simulator_short_name(sim_job.simulator)
-    cmp_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/" + ip_dir_name
-    sim_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_wd/" + ip_dir_name
+    
+    if sub_ip:
+        eff_ip_dir_name = f"{owner_ip.vendor}__{owner_ip.name}"
+        cmp_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/" + eff_ip_dir_name
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd/"  + eff_ip_dir_name
+        work_name = owner_ip.name
+    else:
+        work_name = ip.name
+        cmp_out = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/" + ip_dir_name
+        sim_out = cfg.sim_output_dir + "/" + sim_str + "/sim_wd/" + ip_dir_name
     
     if sim_job.simulator == common.simulators_enum.VIVADO:
+        common.create_dir(cmp_out)
+        common.create_dir(sim_out)
         vlog_compilation_log_path = cfg.sim_dir + "/cmp/" + ip_dir_name + ".viv.vlog.cmp.log"
         vhdl_compilation_log_path = cfg.sim_dir + "/cmp/" + ip_dir_name + ".viv.vhdl.cmp.log"
-        vlog_arg_list = ["-prj "  + ip.vproj_vlog]
-        vlog_arg_list.append("--work " + ip.name + "=" + cmp_out)
+        vlog_arg_list = [f"-prj {ip.path}/{ip.vproj_vlog}"]
+        vlog_arg_list.append("--work " + work_name + "=" + cmp_out)
         vlog_arg_list += vivado_project_default_vlog_compilation_args
         vlog_arg_list += convert_defines(sim_job)
         vlog_arg_list += convert_compilation_args(sim_job)
         vlog_arg_list += convert_deps_to_args(deps, sim_job)
         vlog_arg_list.append("--log " + vlog_compilation_log_path)
-        vhdl_arg_list = ["-prj " + ip.vproj_vhdl]
-        vhdl_arg_list.append("--work " + ip.name + "=" + cmp_out)
+        vhdl_arg_list = [f"-prj {ip.path}/{ip.vproj_vhdl}"]
+        vhdl_arg_list.append("--work " + work_name + "=" + cmp_out)
         vhdl_arg_list += vivado_project_default_vhdl_compilation_args
         vlog_arg_list += convert_defines(sim_job)
         vlog_arg_list += convert_compilation_args(sim_job)
         vlog_arg_list += convert_deps_to_args(deps, sim_job)
         vhdl_arg_list.append("--log " + vhdl_compilation_log_path)
         compilation_command_file = f"{ip_dir_name}.{sim_str}.cmp.xvlog.cmd.txt"
-        write_cmd_to_disk(sim_job, "xvlog", arg_list, compilation_command_file)
+        write_cmd_to_disk(sim_job, "xvlog", vlog_arg_list, compilation_command_file)
         sim_job.bwrap_commands += launch_eda_bin(cfg.vivado_home + "/xvlog", vlog_arg_list, wd=sim_out, dry_run=sim_job.dry_run)
         compilation_command_file = f"{ip_dir_name}.{sim_str}.cmp.xvhdl.cmd.txt"
-        write_cmd_to_disk(sim_job, "xvhdl", arg_list, compilation_command_file)
+        write_cmd_to_disk(sim_job, "xvhdl", vhdl_arg_list, compilation_command_file)
         sim_job.bwrap_commands += launch_eda_bin(cfg.vivado_home + "/xvhdl", vhdl_arg_list, wd=sim_out, dry_run=sim_job.dry_run)
     else:
         common.fatal("Vivado Project IP are not yet compatible with simulator '" + sim_str + "'.")
@@ -697,6 +707,8 @@ def do_elab(ip, sim_job, wd):
         arg_list.append("--log "  + elaboration_log_path)
         arg_list.append("-s "     + ip.name)
         arg_list.append("-L "     + ip.name + "=" + ip_cmp_path)
+        #if ip.has_dut and ip.dut_ip_type == "vivado":
+        #    arg_list.append("-L " + ip.dut.target_ip_model.name)
         for construct in ip.hdl_src_top_constructs:
             if "." in construct:
                 arg_list.append(construct)
@@ -1115,9 +1127,12 @@ def dut_elab_to_arg_list(ip, sim_job):
             if sim_job.simulator != common.simulators_enum.VIVADO:
                 common.fatal("Vivado Projects are currently only compatible with the Vivado simulator.")
             for construct in dut_ip.hdl_src_top_constructs:
-                args.append(construct)
+                args.append(f"{construct}")
             for lib in dut_ip.vproj_libs:
                 args.append("-L " + lib)
+            dut_cmp_out_dir = cfg.sim_output_dir + "/" + sim_str + "/cmp_out/"
+            dut_ip_cmp_path = dut_cmp_out_dir + dut_ip_dir_name
+            #args.append(f"-L {dut_ip.name}={dut_ip_cmp_path}")
         else:
             # Performed by get_dep_list()
             pass
@@ -1236,7 +1251,8 @@ def gen_mflist_file(simulator, ip_vendor, ip_name, path, defines, filelists):
 def gen_flists(ip, deps, sim_job, include_uvm=True):
     flists = []
     for dep in deps:
-        flists.append(get_ip_flist_path(dep, sim_job, include_uvm))
+        if dep.sub_type != "vivado":
+            flists.append(get_ip_flist_path(dep, sim_job, include_uvm))
     flists.append(get_ip_flist_path(ip, sim_job, include_uvm))
     return flists
 
