@@ -256,7 +256,7 @@ def interactive(ip_str, filename=""):
         if 'simulation' in cfg.job_history[ip_str]:
             for sim in cfg.job_history[ip_str]['simulation']:
                 common.dbg("sim job history entry:\n" + str(sim))
-                if sim['type'] == "end":
+                if (sim['type'] == "end") and (sim['is_regression'] == False):
                     sim_log_path = sim['log_path']
                     start = datetime.strptime(sim['timestamp_start'], "%Y/%m/%d-%H:%M:%S")
                     end   = datetime.strptime(sim['timestamp_end'  ], "%Y/%m/%d-%H:%M:%S")
@@ -372,18 +372,18 @@ def parse_sim_log(results, sim_log_path, test):
         for regex in cfg.warning_regexes:
             matches = re.search(regex, line)
             if matches:
-                test.add_warning(matches.group(1))
+                test.add_warning(matches.group(0))
         for regex in cfg.error_regexes:
             matches = re.search(regex, line)
             if matches:
-                test.add_error(matches.group(1))
+                test.add_error(matches.group(0))
                 test.passed = False
                 test.conclusion = "FAILED"
         for regex in cfg.fatal_regexes:
             matches = re.search(regex, line)
             if matches:
                 test.has_fatal = True
-                test.fatal = matches.group(1)
+                test.fatal = matches.group(0)
                 test.passed = False
                 test.add_note("Has simulation fatal error")
                 test.conclusion = "FATAL"
